@@ -5,7 +5,7 @@ from time import sleep
 from typing import Dict, List, Tuple
 from warnings import filterwarnings
 
-import undetected_chromedriver.v2 as uc
+import undetected_chromedriver as uc
 from ecoindex.ecoindex import get_ecoindex
 from ecoindex.models import PageMetrics, PageType, Result, ScreenShot, WindowSize
 from pydantic.networks import HttpUrl
@@ -43,6 +43,7 @@ class EcoindexScraper:
         self.chrome_options.add_argument(f"--window-size={self.window_size}")
         self.chrome_options.add_argument("--no-sandbox")
         self.chrome_options.add_argument("--disable-dev-shm-usage")
+        self.chrome_options.add_argument("--ignore-certificate-errors")
 
         self.capbs = DesiredCapabilities.CHROME.copy()
         self.capbs["goog:loggingPrefs"] = {"performance": "ALL"}
@@ -63,7 +64,12 @@ class EcoindexScraper:
     async def get_page_analysis(
         self,
     ) -> Result:
-        page_metrics, page_type = await self.scrap_page()
+        try:
+            page_metrics, page_type = await self.scrap_page()
+        except Exception as e:
+            self.__del__()
+            raise e
+
         ecoindex = await get_ecoindex(
             dom=page_metrics.nodes,
             size=page_metrics.size,
@@ -140,22 +146,30 @@ class EcoindexScraper:
 
     async def parse_logs(self) -> List[int]:
         downloaded_data = []
+        requests_id = set()
         page_response = False
+        performance_logs = self.driver.get_log("performance")
 
-        for log in self.driver.get_log("performance"):
+        for log in performance_logs:
             message = loads(log["message"])
 
             if (
                 "INFO" == log["level"]
                 and "Network.responseReceived" == message["message"]["method"]
-                and not page_response
+                and message["message"]["params"]["response"]["url"].startswith("http")
             ):
-                page_response = True
-                await self.check_page_response(message["message"]["params"]["response"])
+                requests_id.add(message["message"]["params"]["requestId"])
+
+                if not page_response:
+                    page_response = True
+                    await self.check_page_response(
+                        message["message"]["params"]["response"]
+                    )
 
             if (
                 "INFO" == log["level"]
                 and "Network.loadingFinished" == message["message"]["method"]
+                and message["message"]["params"]["requestId"] in requests_id
             ):
                 downloaded_data.append(
                     loads(log["message"])["message"]["params"]["encodedDataLength"]
@@ -186,11 +200,11 @@ class EcoindexScraper:
             return self.driver.find_element(
                 "xpath", "//meta[@property='og:type']"
             ).get_attribute("content")
-        except (NoSuchElementException):
+        except NoSuchElementException:
             return None
 
     async def get_svg_children_count(self) -> int:
         try:
             return len(self.driver.find_elements("xpath", "//*[local-name()='svg']/*"))
-        except (NoSuchElementException):
+        except NoSuchElementException:
             return 0
